@@ -22,9 +22,9 @@ QtFrameBuffer::QtFrameBuffer(WId id, QObject *parent)
     : FrameBuffer(id, parent)
 {
     fbImage = QPixmap::grabWindow(win).toImage();
-    fb = new char[fbImage.numBytes()];
+    fb = new char[fbImage.byteCount()];
     t = new QTimer(this);
-    connect(t, SIGNAL(timeout()), SLOT(updateFrameBuffer()));
+    connect(t, &QTimer::timeout, this, &QtFrameBuffer::updateFrameBuffer);
 }
 
 
@@ -67,6 +67,7 @@ void QtFrameBuffer::getServerFormat(rfbPixelFormat &format)
 void QtFrameBuffer::updateFrameBuffer()
 {
     QImage img = QPixmap::grabWindow(win).toImage();
+#if 0 // This is actually slower than updating the whole desktop...
     QSize imgSize = img.size();
 
 
@@ -74,8 +75,6 @@ void QtFrameBuffer::updateFrameBuffer()
     // fbImage is the previous version of the image,
     // img is the current one
 
-#if 0 // This is actually slower than updating the whole desktop...
-
     QImage map(imgSize, QImage::Format_Mono);
     map.fill(0);
 
@@ -94,7 +93,7 @@ void QtFrameBuffer::updateFrameBuffer()
     tiles.append(img.rect());
 #endif
 
-    memcpy(fb, (const char *)img.bits(), img.numBytes());
+    memcpy(fb, (const char *)img.bits(), img.byteCount());
     fbImage = img;
 
 }
